# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Box',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('label', models.CharField(max_length=100, db_index=True)),
                ('content', models.TextField(blank=True)),
                ('last_updated', models.DateTimeField(default=django.utils.timezone.now)),
                ('created_by', models.ForeignKey(related_name='boxes', to=settings.AUTH_USER_MODEL)),
                ('last_updated_by', models.ForeignKey(related_name='updated_boxes', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'boxes',
            },
        ),
    ]



class DefaultHookSet(object):

    def parse_content(self, content):
        return content


class HookProxy(object):

    def __getattr__(self, attr):
        from .conf import settings  # if put globally there is a race condition
        return getattr(settings.PINAX_BOXES_HOOKSET, attr)


hookset = HookProxy()



from django.contrib import admin

try:
    import reversion
    AdminBase = reversion.VersionAdmin
except ImportError:
    AdminBase = admin.ModelAdmin

from .models import Box


class BoxAdmin(AdminBase):
    list_display = ["label", "created_by", "last_updated_by", "last_updated"]
    search_fields = ["content"]


admin.site.register(Box, BoxAdmin)
